'use strict';

var path = require('path');
var notify = require('growl');
var finished = require('tap-finished');

process.stdin.pipe(process.stdout);

function message(failed, total) {
  return failed ?
    failed + ' of ' + total + ' tests failed' :
    total + ' tests passed';
}

function image(name) {
  return path.join(__dirname, './images/', name + '.png');
}

function growlOptions(results) {
  var failed = results.fail.length + results.errors.length;
  var total = results.plan.end;

  return {
    name: 'tap',
    title: failed ? 'Failed' : 'Passed',
    image: image(failed ? 'error' : 'ok'),
    message: message(failed, total)
  };
}

module.exports = function tapGrowl() {
  var notifier = finished(function(results) {
    var options = growlOptions(results);
    notify(options.message, options);
    setImmediate(tapGrowl);
  });

  process.stdin.pipe(notifier);
};
